@@ -19,6 +19,12 @@ PROJ_DIR = os.path.dirname(JBUTILS_DIR)
 UTILS_PATH = os.path.join(JBUTILS_DIR, "utils", "utils.py")
 
 _parser = argparse.ArgumentParser(description=__doc__)
+_parser.add_argument(
+    "--get-installs",
+    "-i",
+    action="store_true",
+    help="Get poetry add command for jbutils packages",
+)
 cmn_handler = jbutils.add_common_args(_parser, UTILS_PATH, proj_dir=PROJ_DIR)
 args = _parser.parse_args()
 
@@ -27,6 +33,11 @@ def main() -> None:
     cfg = Configurator(app_name="cfgtest")
     dpath = "saved_data.test3.yaml"
     cmn_handler()
+    if args.get_installs:
+        os.chdir(PROJ_DIR)
+        jbutils.get_poetry_installs()
+        return
+
     sys.exit(
         embed(
             globals=globals(),
