@@ -4,7 +4,10 @@ from jbutils.utils.utils import (
     cmdx,
     copy_to_clipboard,
     get_nested,
+    joiner,
     parse_csv_line,
+    p_exists,
+    p_join,
     pretty_print,
     read_file,
     set_encoding,
@@ -18,7 +21,10 @@ __all__ = [
     "cmdx",
     "copy_to_clipboard",
     "get_nested",
+    "joiner",
     "parse_csv_line",
+    "p_exists",
+    "p_join",
     "pretty_print",
     "read_file",
     "set_encoding",
