@@ -29,10 +29,12 @@ from time import time
 from typing import Any, Optional
 
 import jsonlines
+import pymupdf
 
 from jsonlines.jsonlines import JSONValue
 from PIL import Image, ImageFile
 from PIL.ImageFile import ImageFile
+from pymupdf import Document
 from ruamel.yaml import YAML
 from ruamel.yaml.comments import CommentedMap, CommentedSeq
 from ruamel.yaml.tokens import CommentToken
@@ -109,7 +111,7 @@ def read_file(
     as_dicts: bool = False,
     *args,
     **kwargs,
-) -> str | dict | list | ImageFile:
+) -> str | dict | list | ImageFile | Document:
     """Read data from a file
 
     Args:
@@ -168,6 +170,8 @@ def read_file(
 
                     return [dict(zip(cols, vals)) for vals in data]
                 return data
+            case ".pdf":
+                return pymupdf.open(fs)
             case _:
                 if ext.lower() in IMAGE_EXTS:
                     return Image.open(fs)
@@ -1112,7 +1116,9 @@ def extract_comment(data: CommentedMap | CommentedSeq) -> str:
     return comment[0].value
 
 
-def joiner(path: str = "") -> StrVarArgsFn:
+def joiner(path: str = "", abs_path: bool = False) -> StrVarArgsFn:
+    if abs_path:
+        return lambda *x: os.path.abspath(os.path.join(path, *x))
     return lambda *x: os.path.join(path, *x)
 
 
@@ -1131,4 +1137,31 @@ def profile(func: Callable, *args, **kwargs) -> float:
     return round((time() - start) * 1000, 3)
 
 
+def get_poetry_installs(incldue_vers: bool = True):
+    out: str = cmdx("poetry show", print_out=False)  # type: ignore
+    lines = out.split("\n")
+
+    line_re = re.compile(r"\s+")
+
+    cmd = "poetry add "
+
+    for line in lines:
+        matches = line_re.split(line)
+        if len(matches) < 2:
+            continue
+
+        pkg = matches[0]
+        version = matches[1]
+        if incldue_vers:
+            cmd += f"{pkg}=={version} "
+        else:
+            cmd += f"{pkg} "
+
+    try:
+        copy_to_clipboard(cmd)
+        print("Poetry installs command copied to clipboard")
+    except:
+        print(cmd)
+
+
 p_exists.__doc__ = os.path.exists.__doc__
